public let MBL_MW_SENSOR_FUSION_CALIBRATION_ACCURACY_LOW = 1
public let MBL_MW_ADDRESS_TYPE_PRIVATE_NON_RESOLVABLE = 3
public let MBL_MW_STATUS_ERROR_ENABLE_NOTIFY = 64
public let MBL_MW_SETTINGS_BATTERY_CHARGE_INDEX = 1
public let MBL_MW_LED_REPEAT_INDEFINITELY = 255
public let MBL_MW_ACC_ACCEL_X_AXIS_INDEX = 0
public let MBL_MW_ADDRESS_TYPE_PRIVATE_RESOLVABLE = 2
public let MBL_MW_MODULE_BARO_TYPE_BMP280 = 0
public let MBL_MW_SENSOR_FUSION_CALIBRATION_ACCURACY_MEDIUM = 2
public let MBL_MW_STATUS_ERROR_SERIALIZATION_FORMAT = 32
public let MBL_MW_STATUS_WARNING_UNEXPECTED_SENSOR_DATA = 1
public let MBL_MW_STATUS_ERROR_TIMEOUT = 16
public let MBL_MW_STATUS_OK = 0
public let MBL_MW_SETTINGS_BATTERY_VOLTAGE_INDEX = 0
public let MBL_MW_ADDRESS_TYPE_PUBLIC = 0
public let MBL_MW_ADDRESS_TYPE_RANDOM_STATIC = 1
public let MBL_MW_STATUS_WARNING_INVALID_PROCESSOR_TYPE = 2
public let MBL_MW_STATUS_WARNING_INVALID_RESPONSE = 8
public let MBL_MW_MODULE_BARO_TYPE_BME280 = 1
public let MBL_MW_MODULE_ACC_TYPE_BMI160 = 1
public let MBL_MW_MODULE_ACC_TYPE_BMA255 = 3
public let MBL_MW_MAG_BFIELD_Y_AXIS_INDEX = 1
public let MBL_MW_CD_TCS34725_ADC_CLEAR_INDEX = 0
public let MBL_MW_STATUS_ERROR_UNSUPPORTED_PROCESSOR = 4
public let MBL_MW_GYRO_ROTATION_Y_AXIS_INDEX = 1
public let MBL_MW_CD_TCS34725_ADC_RED_INDEX = 1
public let MBL_MW_SENSOR_FUSION_CALIBRATION_ACCURACY_HIGH = 3
public let MBL_MW_MODULE_TYPE_NA = -1
public let MBL_MW_SENSOR_FUSION_CALIBRATION_ACCURACY_UNRELIABLE = 0
public let MBL_MW_CD_TCS34725_ADC_GREEN_INDEX = 2
public let MBL_MW_MAG_BFIELD_X_AXIS_INDEX = 0
public let MBL_MW_GPIO_UNUSED_PIN = 255
public let MBL_MW_ACC_ACCEL_Z_AXIS_INDEX = 2
public let MBL_MW_GYRO_ROTATION_Z_AXIS_INDEX = 2
public let MBL_MW_MAG_BFIELD_Z_AXIS_INDEX = 2
public let MBL_MW_CD_TCS34725_ADC_BLUE_INDEX = 3
public let MBL_MW_ACC_ACCEL_Y_AXIS_INDEX = 1
public let MBL_MW_MODULE_ACC_TYPE_MMA8452Q = 0
public let MBL_MW_GYRO_ROTATION_X_AXIS_INDEX = 0
